@@ -16,9 +16,12 @@ Sorted dict implementations:
 
 """
 
+import sys
+import warnings
 from collections import ItemsView, KeysView, ValuesView, Sequence
 
 from .sortedlist import SortedList, recursive_repr
+from .sortedset import SortedSet
 
 
 class SortedDict(dict):
@@ -175,11 +178,6 @@ class SortedDict(dict):
             self.bisect_key = _list.bisect_key
             self.irange_key = _list.irange_key
 
-        # GrantJ 2018-05-21 Temporary fix for improved backwards compatibility
-        # with V1.
-
-        self.iloc = SortedKeysView(self)
-
         self._update(*args, **kwargs)
 
 
@@ -193,7 +191,30 @@ class SortedDict(dict):
         return self._key
 
 
+    @property
+    def iloc(self):
+        """Cached reference of sorted keys view.
+
+        Deprecated in version 2 of Sorted Containers. Use
+        :func:`SortedDict.keys` instead.
+
+        """
+        # pylint: disable=attribute-defined-outside-init
+        try:
+            return self._iloc
+        except AttributeError:
+            warnings.warn(
+                'sorted_dict.iloc is deprecated.'
+                ' Use SortedDict.keys() instead.',
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            _iloc = self._iloc = SortedKeysView(self)
+            return _iloc
+
+
     def clear(self):
+
         """Remove all items from sorted dict.
 
         Runtime complexity: `O(n)`
@@ -337,6 +358,28 @@ class SortedDict(dict):
         return SortedValuesView(self)
 
 
+    if sys.hexversion < 0x03000000:
+        def __make_raise_attributeerror(original, alternate):
+            # pylint: disable=no-self-argument
+            message = (
+                'SortedDict.{original}() is not implemented.'
+                ' Use SortedDict.{alternate}() instead.'
+            ).format(original=original, alternate=alternate)
+            def method(self):
+                # pylint: disable=missing-docstring,unused-argument
+                raise AttributeError(message)
+            method.__name__ = original
+            method.__doc__ = message
+            return property(method)
+
+        iteritems = __make_raise_attributeerror('iteritems', 'items')
+        iterkeys = __make_raise_attributeerror('iterkeys', 'keys')
+        itervalues = __make_raise_attributeerror('itervalues', 'values')
+        viewitems = __make_raise_attributeerror('viewitems', 'items')
+        viewkeys = __make_raise_attributeerror('viewkeys', 'keys')
+        viewvalues = __make_raise_attributeerror('viewvalues', 'values')
+
+
     class _NotGiven(object):
         # pylint: disable=too-few-public-methods
         def __repr__(self):
@@ -554,7 +597,7 @@ def _view_delitem(self, index):
 
     ``view.__delitem__(index)`` <==> ``del view[index]``
 
-    Support slicing.
+    Supports slicing.
 
     Runtime complexity: `O(log(n))` -- approximate.
 
@@ -598,6 +641,11 @@ class SortedKeysView(KeysView, Sequence):
     __slots__ = ()
 
 
+    @classmethod
+    def _from_iterable(cls, it):
+        return SortedSet(it)
+
+
     def __getitem__(self, index):
         """Lookup key at `index` in sorted keys views.
 
@@ -642,6 +690,11 @@ class SortedItemsView(ItemsView, Sequence):
     __slots__ = ()
 
 
+    @classmethod
+    def _from_iterable(cls, it):
+        return SortedSet(it)
+
+
     def __getitem__(self, index):
         """Lookup item at `index` in sorted items view.
 
@@ -688,7 +741,7 @@ class SortedValuesView(ValuesView, Sequence):
 
     When the sorted dict's values change, the view reflects those changes.
 
-    The values view implements the set and sequence abstract base classes.
+    The values view implements the sequence abstract base class.
 
     """
     __slots__ = ()
